/// <reference types="node" />
import { ServerResponse, IncomingMessage } from 'http';
import { Macroable } from 'macroable';
import { ResponseContract, CastableHeader, LazyBody, ResponseContentType, ResponseStream } from './ResponseContract';
declare type Config = {
    etag: boolean;
    jsonpCallbackName: string;
};
export declare class Response extends Macroable implements ResponseContract {
    request: IncomingMessage;
    response: ServerResponse;
    explicitEnd: boolean;
    lazyBody: LazyBody | null;
    private _config;
    protected static _macros: {};
    protected static _getters: {};
    constructor(request: IncomingMessage, response: ServerResponse, config: Partial<Config>);
    readonly hasLazyBody: boolean;
    readonly finished: boolean;
    readonly headersSent: boolean;
    readonly isPending: boolean;
    private _castHeaderValue;
    private _writeBody;
    getHeader(key: string): string | number | string[] | undefined;
    header(key: string, value: CastableHeader): this;
    append(key: string, value: CastableHeader): this;
    safeHeader(key: string, value: CastableHeader): this;
    removeHeader(key: string): this;
    status(code: number): this;
    type(type: string, charset?: string): this;
    vary(field: string): this;
    setEtag(body: any, weak?: boolean): this;
    fresh(): boolean;
    buildResponseBody(body: any): {
        body: any;
        type: ResponseContentType;
        originalType?: string;
    };
    send(body: any, generateEtag?: boolean): void;
    json(body: any, generateEtag?: boolean): void;
    jsonp(body: any, callbackName?: string, generateEtag?: boolean): void;
    stream(body: ResponseStream, raiseErrors?: boolean): Promise<Error | void>;
    download(filePath: string, generateEtag?: boolean, raiseErrors?: boolean): Promise<void | Error>;
    attachment(filePath: string, name?: string, disposition?: string, generateEtag?: boolean, raiseErrors?: boolean): Promise<void | Error>;
    location(url: string): this;
    redirect(url: string, sendQueryParams?: boolean, statusCode?: number): void;
    finish(): void;
}
export {};
