/// <reference types="node" />
import { ServerResponse, IncomingMessage } from 'http';
export declare type CastableHeader = string | number | boolean | string[] | number[] | boolean[];
export declare type ResponseContentType = 'text/html' | 'text/plain' | 'application/octet-stream' | 'application/json' | 'unknown' | 'null';
export declare type ResponseStream = NodeJS.ReadStream | NodeJS.ReadWriteStream | NodeJS.ReadableStream;
export declare type LazyBody = {
    writer: any;
    args: any[];
};
export interface ResponseContract {
    explicitEnd: boolean;
    hasLazyBody: boolean;
    lazyBody: LazyBody | null;
    finished: boolean;
    headersSent: boolean;
    isPending: boolean;
    request: IncomingMessage;
    response: ServerResponse;
    getHeader(key: string): string | string[] | number | undefined;
    header(key: string, value: CastableHeader): this;
    append(key: string, value: CastableHeader): this;
    safeHeader(key: string, value: CastableHeader): this;
    removeHeader(key: string): this;
    status(code: number): this;
    type(type: string, charset?: string): this;
    vary(field: string): this;
    setEtag(body: any, weak?: boolean): this;
    buildResponseBody(body: any): {
        body: any;
        type: ResponseContentType;
        originalType?: string;
    };
    send(body: any, generateEtag?: boolean): void;
    json(body: any, generateEtag?: boolean): void;
    jsonp(body: any, callbackName?: string, generateEtag?: boolean): void;
    stream(stream: ResponseStream, raiseErrors?: boolean): Promise<Error | void>;
    download(filePath: string, generateEtag?: boolean, raiseErrors?: boolean): Promise<Error | void>;
    attachment(filePath: string, name?: string, disposition?: string, generateEtag?: boolean, raiseErrors?: boolean): Promise<Error | void>;
    location(url: string): this;
    redirect(url: string, reflectQueryParams?: boolean, statusCode?: number): void;
    finish(): void;
}
